@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,7 +26,10 @@
 #include <sonnet/spellcheckdecorator.h>
 #include <sonnet/speller.h>
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-#include <texttospeech/texttospeech.h>
+#include <KPIMTextEditTextToSpeech/TextToSpeech>
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeech>
 #endif
 
 #include <KColorScheme>
@@ -41,7 +44,6 @@
 #include <QScrollBar>
 #include <QTextCursor>
 #include <QTextDocumentFragment>
-#include <kwidgetsaddons_version.h>
 
 using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN RichTextEditor::RichTextEditorPrivate
@@ -194,14 +196,23 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         }
         if (searchSupport()) {
             popup->addSeparator();
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
             QAction *findAct =
                 popup->addAction(KStandardGuiItem::find().icon(), KStandardGuiItem::find().text(), this, &RichTextEditor::findText, Qt::Key_F | Qt::CTRL);
+#else
+            QAction *findAct =
+                popup->addAction(KStandardGuiItem::find().icon(), KStandardGuiItem::find().text(), Qt::Key_F | Qt::CTRL, this, &RichTextEditor::findText);
+#endif
             if (emptyDocument) {
                 findAct->setEnabled(false);
             }
             popup->addSeparator();
             if (!isReadOnly()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
                 QAction *act = popup->addAction(i18n("Replace..."), this, &RichTextEditor::replaceText, Qt::Key_R | Qt::CTRL);
+#else
+                QAction *act = popup->addAction(i18n("Replace..."), Qt::Key_R | Qt::CTRL, this, &RichTextEditor::replaceText);
+#endif
                 if (emptyDocument) {
                     act->setEnabled(false);
                 }
@@ -262,12 +273,17 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             connect(allowTabAction, &QAction::triggered, this, &RichTextEditor::slotAllowTab);
         }
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-        if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
-            if (!emptyDocument) {
-                QAction *speakAction = popup->addAction(i18n("Speak Text"));
-                speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
-                connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
-            }
+        if (!emptyDocument) {
+            QAction *speakAction = popup->addAction(i18n("Speak Text"));
+            speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+            connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
+        }
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+        if (!emptyDocument) {
+            QAction *speakAction = popup->addAction(i18n("Speak Text"));
+            speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+            connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
         }
 #endif
         if (webShortcutSupport() && textCursor().hasSelection()) {
@@ -457,20 +473,12 @@ void RichTextEditor::checkSpelling(bool force)
     auto backgroundSpellCheck = new Sonnet::BackgroundChecker;
     if (backgroundSpellCheck->speller().availableBackends().isEmpty()) {
         if (force) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             const int answer = KMessageBox::questionTwoActions(this,
-#else
-            const int answer = KMessageBox::questionYesNo(this,
-#endif
                                                                i18n("No backend available for spell checking. Do you want to send the email anyways?"),
                                                                QString(),
                                                                KGuiItem(i18nc("@action:button", "Send"), QStringLiteral("mail-send")),
                                                                KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            if (answer == KMessageBox::Yes) {
-#endif
                 Q_EMIT spellCheckingFinished();
             }
         } else {
